# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RegistryEnterpriseInstanceArgs', 'RegistryEnterpriseInstance']

@pulumi.input_type
class RegistryEnterpriseInstanceArgs:
    def __init__(__self__, *,
                 instance_name: pulumi.Input[builtins.str],
                 instance_type: pulumi.Input[builtins.str],
                 payment_type: pulumi.Input[builtins.str],
                 custom_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
                 default_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
                 image_scanner: Optional[pulumi.Input[builtins.str]] = None,
                 kms_encrypted_password: Optional[pulumi.Input[builtins.str]] = None,
                 kms_encryption_context: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 renew_period: Optional[pulumi.Input[builtins.int]] = None,
                 renewal_status: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a RegistryEnterpriseInstance resource.
        :param pulumi.Input[builtins.str] instance_name: InstanceName
        :param pulumi.Input[builtins.str] instance_type: The Value configuration of the Group 1 attribute of Container Mirror Service Enterprise Edition. Valid values:
               - `Basic`: Basic instance
               - `Standard`: Standard instance
               - `Advanced`: Advanced Edition Instance
        :param pulumi.Input[builtins.str] payment_type: Payment type, value:
               - Subscription: Prepaid.
        :param pulumi.Input[builtins.str] custom_oss_bucket: Custom OSS Bucket name
        :param pulumi.Input[builtins.str] default_oss_bucket: Whether to use the default OSS Bucket. Value:
        :param pulumi.Input[builtins.str] image_scanner: The security scan engine used by the Enterprise Edition of Container Image Service. Value:
               - `ACR`: Uses the Trivy scan engine provided by default.
               - `SAS`: uses the enhanced cloud security scan engine.
        :param pulumi.Input[builtins.str] kms_encrypted_password: An KMS encrypts password used to an instance. If the `password` is filled in, this field will be ignored.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] kms_encryption_context: An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        :param pulumi.Input[builtins.str] password: Login password, 8-32 digits, must contain at least two letters, symbols, or numbers
        :param pulumi.Input[builtins.int] period: Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.
               
               > **NOTE:**  must be set when creating a prepaid instance.
        :param pulumi.Input[builtins.int] renew_period: Automatic renewal cycle, in months.
               
               > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        :param pulumi.Input[builtins.str] renewal_status: Automatic renewal status, value:
               - AutoRenewal: automatic renewal.
               - ManualRenewal: manual renewal.
               
               Default ManualRenewal.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "payment_type", payment_type)
        if custom_oss_bucket is not None:
            pulumi.set(__self__, "custom_oss_bucket", custom_oss_bucket)
        if default_oss_bucket is not None:
            pulumi.set(__self__, "default_oss_bucket", default_oss_bucket)
        if image_scanner is not None:
            pulumi.set(__self__, "image_scanner", image_scanner)
        if kms_encrypted_password is not None:
            pulumi.set(__self__, "kms_encrypted_password", kms_encrypted_password)
        if kms_encryption_context is not None:
            pulumi.set(__self__, "kms_encryption_context", kms_encryption_context)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if renew_period is not None:
            pulumi.set(__self__, "renew_period", renew_period)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Input[builtins.str]:
        """
        InstanceName
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Input[builtins.str]:
        """
        The Value configuration of the Group 1 attribute of Container Mirror Service Enterprise Edition. Valid values:
        - `Basic`: Basic instance
        - `Standard`: Standard instance
        - `Advanced`: Advanced Edition Instance
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[builtins.str]:
        """
        Payment type, value:
        - Subscription: Prepaid.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="customOssBucket")
    def custom_oss_bucket(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom OSS Bucket name
        """
        return pulumi.get(self, "custom_oss_bucket")

    @custom_oss_bucket.setter
    def custom_oss_bucket(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_oss_bucket", value)

    @property
    @pulumi.getter(name="defaultOssBucket")
    def default_oss_bucket(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to use the default OSS Bucket. Value:
        """
        return pulumi.get(self, "default_oss_bucket")

    @default_oss_bucket.setter
    def default_oss_bucket(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "default_oss_bucket", value)

    @property
    @pulumi.getter(name="imageScanner")
    def image_scanner(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The security scan engine used by the Enterprise Edition of Container Image Service. Value:
        - `ACR`: Uses the Trivy scan engine provided by default.
        - `SAS`: uses the enhanced cloud security scan engine.
        """
        return pulumi.get(self, "image_scanner")

    @image_scanner.setter
    def image_scanner(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_scanner", value)

    @property
    @pulumi.getter(name="kmsEncryptedPassword")
    def kms_encrypted_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        An KMS encrypts password used to an instance. If the `password` is filled in, this field will be ignored.
        """
        return pulumi.get(self, "kms_encrypted_password")

    @kms_encrypted_password.setter
    def kms_encrypted_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kms_encrypted_password", value)

    @property
    @pulumi.getter(name="kmsEncryptionContext")
    def kms_encryption_context(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        """
        return pulumi.get(self, "kms_encryption_context")

    @kms_encryption_context.setter
    def kms_encryption_context(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "kms_encryption_context", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Login password, 8-32 digits, must contain at least two letters, symbols, or numbers
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.

        > **NOTE:**  must be set when creating a prepaid instance.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Automatic renewal cycle, in months.

        > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        """
        return pulumi.get(self, "renew_period")

    @renew_period.setter
    def renew_period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "renew_period", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Automatic renewal status, value:
        - AutoRenewal: automatic renewal.
        - ManualRenewal: manual renewal.

        Default ManualRenewal.
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "renewal_status", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)


@pulumi.input_type
class _RegistryEnterpriseInstanceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 custom_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
                 default_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 image_scanner: Optional[pulumi.Input[builtins.str]] = None,
                 instance_endpoints: Optional[pulumi.Input[Sequence[pulumi.Input['RegistryEnterpriseInstanceInstanceEndpointArgs']]]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 kms_encrypted_password: Optional[pulumi.Input[builtins.str]] = None,
                 kms_encryption_context: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 renew_period: Optional[pulumi.Input[builtins.int]] = None,
                 renewal_status: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RegistryEnterpriseInstance resources.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] created_time: . Field 'created_time' has been deprecated from provider version 1.235.0. New field 'create_time' instead.
        :param pulumi.Input[builtins.str] custom_oss_bucket: Custom OSS Bucket name
        :param pulumi.Input[builtins.str] default_oss_bucket: Whether to use the default OSS Bucket. Value:
        :param pulumi.Input[builtins.str] end_time: Expiration Time
        :param pulumi.Input[builtins.str] image_scanner: The security scan engine used by the Enterprise Edition of Container Image Service. Value:
               - `ACR`: Uses the Trivy scan engine provided by default.
               - `SAS`: uses the enhanced cloud security scan engine.
        :param pulumi.Input[Sequence[pulumi.Input['RegistryEnterpriseInstanceInstanceEndpointArgs']]] instance_endpoints: (Available since v1.240.0) Instance Network Access Endpoint List
        :param pulumi.Input[builtins.str] instance_name: InstanceName
        :param pulumi.Input[builtins.str] instance_type: The Value configuration of the Group 1 attribute of Container Mirror Service Enterprise Edition. Valid values:
               - `Basic`: Basic instance
               - `Standard`: Standard instance
               - `Advanced`: Advanced Edition Instance
        :param pulumi.Input[builtins.str] kms_encrypted_password: An KMS encrypts password used to an instance. If the `password` is filled in, this field will be ignored.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] kms_encryption_context: An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        :param pulumi.Input[builtins.str] password: Login password, 8-32 digits, must contain at least two letters, symbols, or numbers
        :param pulumi.Input[builtins.str] payment_type: Payment type, value:
               - Subscription: Prepaid.
        :param pulumi.Input[builtins.int] period: Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.
               
               > **NOTE:**  must be set when creating a prepaid instance.
        :param pulumi.Input[builtins.str] region_id: RegionId
        :param pulumi.Input[builtins.int] renew_period: Automatic renewal cycle, in months.
               
               > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        :param pulumi.Input[builtins.str] renewal_status: Automatic renewal status, value:
               - AutoRenewal: automatic renewal.
               - ManualRenewal: manual renewal.
               
               Default ManualRenewal.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        :param pulumi.Input[builtins.str] status: Instance Status
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if created_time is not None:
            warnings.warn("""Field 'created_time' has been deprecated since provider version 1.235.0. New field 'create_time' instead.""", DeprecationWarning)
            pulumi.log.warn("""created_time is deprecated: Field 'created_time' has been deprecated since provider version 1.235.0. New field 'create_time' instead.""")
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if custom_oss_bucket is not None:
            pulumi.set(__self__, "custom_oss_bucket", custom_oss_bucket)
        if default_oss_bucket is not None:
            pulumi.set(__self__, "default_oss_bucket", default_oss_bucket)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if image_scanner is not None:
            pulumi.set(__self__, "image_scanner", image_scanner)
        if instance_endpoints is not None:
            pulumi.set(__self__, "instance_endpoints", instance_endpoints)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if kms_encrypted_password is not None:
            pulumi.set(__self__, "kms_encrypted_password", kms_encrypted_password)
        if kms_encryption_context is not None:
            pulumi.set(__self__, "kms_encryption_context", kms_encryption_context)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if renew_period is not None:
            pulumi.set(__self__, "renew_period", renew_period)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="createdTime")
    @_utilities.deprecated("""Field 'created_time' has been deprecated since provider version 1.235.0. New field 'create_time' instead.""")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        . Field 'created_time' has been deprecated from provider version 1.235.0. New field 'create_time' instead.
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="customOssBucket")
    def custom_oss_bucket(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom OSS Bucket name
        """
        return pulumi.get(self, "custom_oss_bucket")

    @custom_oss_bucket.setter
    def custom_oss_bucket(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_oss_bucket", value)

    @property
    @pulumi.getter(name="defaultOssBucket")
    def default_oss_bucket(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to use the default OSS Bucket. Value:
        """
        return pulumi.get(self, "default_oss_bucket")

    @default_oss_bucket.setter
    def default_oss_bucket(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "default_oss_bucket", value)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Expiration Time
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter(name="imageScanner")
    def image_scanner(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The security scan engine used by the Enterprise Edition of Container Image Service. Value:
        - `ACR`: Uses the Trivy scan engine provided by default.
        - `SAS`: uses the enhanced cloud security scan engine.
        """
        return pulumi.get(self, "image_scanner")

    @image_scanner.setter
    def image_scanner(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_scanner", value)

    @property
    @pulumi.getter(name="instanceEndpoints")
    def instance_endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RegistryEnterpriseInstanceInstanceEndpointArgs']]]]:
        """
        (Available since v1.240.0) Instance Network Access Endpoint List
        """
        return pulumi.get(self, "instance_endpoints")

    @instance_endpoints.setter
    def instance_endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RegistryEnterpriseInstanceInstanceEndpointArgs']]]]):
        pulumi.set(self, "instance_endpoints", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        InstanceName
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Value configuration of the Group 1 attribute of Container Mirror Service Enterprise Edition. Valid values:
        - `Basic`: Basic instance
        - `Standard`: Standard instance
        - `Advanced`: Advanced Edition Instance
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="kmsEncryptedPassword")
    def kms_encrypted_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        An KMS encrypts password used to an instance. If the `password` is filled in, this field will be ignored.
        """
        return pulumi.get(self, "kms_encrypted_password")

    @kms_encrypted_password.setter
    def kms_encrypted_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kms_encrypted_password", value)

    @property
    @pulumi.getter(name="kmsEncryptionContext")
    def kms_encryption_context(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        """
        return pulumi.get(self, "kms_encryption_context")

    @kms_encryption_context.setter
    def kms_encryption_context(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "kms_encryption_context", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Login password, 8-32 digits, must contain at least two letters, symbols, or numbers
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Payment type, value:
        - Subscription: Prepaid.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.

        > **NOTE:**  must be set when creating a prepaid instance.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RegionId
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Automatic renewal cycle, in months.

        > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        """
        return pulumi.get(self, "renew_period")

    @renew_period.setter
    def renew_period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "renew_period", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Automatic renewal status, value:
        - AutoRenewal: automatic renewal.
        - ManualRenewal: manual renewal.

        Default ManualRenewal.
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "renewal_status", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Instance Status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:cr/registryEnterpriseInstance:RegistryEnterpriseInstance")
class RegistryEnterpriseInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
                 default_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
                 image_scanner: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 kms_encrypted_password: Optional[pulumi.Input[builtins.str]] = None,
                 kms_encryption_context: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 renew_period: Optional[pulumi.Input[builtins.int]] = None,
                 renewal_status: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a CR Instance resource.

        For information about Container Registry Enterprise Edition instances and how to use it, see [Create a Instance](https://www.alibabacloud.com/help/en/doc-detail/208144.htm)

        > **NOTE:** Available since v1.124.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000000,
            max=99999999)
        default_registry_enterprise_instance = alicloud.cr.RegistryEnterpriseInstance("default",
            payment_type="Subscription",
            period=1,
            renew_period=1,
            renewal_status="AutoRenewal",
            instance_type="Advanced",
            instance_name=f"{name}-{default['result']}")
        ```

        ## Import

        CR Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cr/registryEnterpriseInstance:RegistryEnterpriseInstance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] custom_oss_bucket: Custom OSS Bucket name
        :param pulumi.Input[builtins.str] default_oss_bucket: Whether to use the default OSS Bucket. Value:
        :param pulumi.Input[builtins.str] image_scanner: The security scan engine used by the Enterprise Edition of Container Image Service. Value:
               - `ACR`: Uses the Trivy scan engine provided by default.
               - `SAS`: uses the enhanced cloud security scan engine.
        :param pulumi.Input[builtins.str] instance_name: InstanceName
        :param pulumi.Input[builtins.str] instance_type: The Value configuration of the Group 1 attribute of Container Mirror Service Enterprise Edition. Valid values:
               - `Basic`: Basic instance
               - `Standard`: Standard instance
               - `Advanced`: Advanced Edition Instance
        :param pulumi.Input[builtins.str] kms_encrypted_password: An KMS encrypts password used to an instance. If the `password` is filled in, this field will be ignored.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] kms_encryption_context: An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        :param pulumi.Input[builtins.str] password: Login password, 8-32 digits, must contain at least two letters, symbols, or numbers
        :param pulumi.Input[builtins.str] payment_type: Payment type, value:
               - Subscription: Prepaid.
        :param pulumi.Input[builtins.int] period: Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.
               
               > **NOTE:**  must be set when creating a prepaid instance.
        :param pulumi.Input[builtins.int] renew_period: Automatic renewal cycle, in months.
               
               > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        :param pulumi.Input[builtins.str] renewal_status: Automatic renewal status, value:
               - AutoRenewal: automatic renewal.
               - ManualRenewal: manual renewal.
               
               Default ManualRenewal.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RegistryEnterpriseInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a CR Instance resource.

        For information about Container Registry Enterprise Edition instances and how to use it, see [Create a Instance](https://www.alibabacloud.com/help/en/doc-detail/208144.htm)

        > **NOTE:** Available since v1.124.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000000,
            max=99999999)
        default_registry_enterprise_instance = alicloud.cr.RegistryEnterpriseInstance("default",
            payment_type="Subscription",
            period=1,
            renew_period=1,
            renewal_status="AutoRenewal",
            instance_type="Advanced",
            instance_name=f"{name}-{default['result']}")
        ```

        ## Import

        CR Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cr/registryEnterpriseInstance:RegistryEnterpriseInstance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param RegistryEnterpriseInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RegistryEnterpriseInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
                 default_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
                 image_scanner: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 kms_encrypted_password: Optional[pulumi.Input[builtins.str]] = None,
                 kms_encryption_context: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 renew_period: Optional[pulumi.Input[builtins.int]] = None,
                 renewal_status: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RegistryEnterpriseInstanceArgs.__new__(RegistryEnterpriseInstanceArgs)

            __props__.__dict__["custom_oss_bucket"] = custom_oss_bucket
            __props__.__dict__["default_oss_bucket"] = default_oss_bucket
            __props__.__dict__["image_scanner"] = image_scanner
            if instance_name is None and not opts.urn:
                raise TypeError("Missing required property 'instance_name'")
            __props__.__dict__["instance_name"] = instance_name
            if instance_type is None and not opts.urn:
                raise TypeError("Missing required property 'instance_type'")
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["kms_encrypted_password"] = kms_encrypted_password
            __props__.__dict__["kms_encryption_context"] = kms_encryption_context
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["period"] = period
            __props__.__dict__["renew_period"] = renew_period
            __props__.__dict__["renewal_status"] = renewal_status
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["end_time"] = None
            __props__.__dict__["instance_endpoints"] = None
            __props__.__dict__["region_id"] = None
            __props__.__dict__["status"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(RegistryEnterpriseInstance, __self__).__init__(
            'alicloud:cr/registryEnterpriseInstance:RegistryEnterpriseInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            custom_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
            default_oss_bucket: Optional[pulumi.Input[builtins.str]] = None,
            end_time: Optional[pulumi.Input[builtins.str]] = None,
            image_scanner: Optional[pulumi.Input[builtins.str]] = None,
            instance_endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RegistryEnterpriseInstanceInstanceEndpointArgs', 'RegistryEnterpriseInstanceInstanceEndpointArgsDict']]]]] = None,
            instance_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_type: Optional[pulumi.Input[builtins.str]] = None,
            kms_encrypted_password: Optional[pulumi.Input[builtins.str]] = None,
            kms_encryption_context: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            payment_type: Optional[pulumi.Input[builtins.str]] = None,
            period: Optional[pulumi.Input[builtins.int]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            renew_period: Optional[pulumi.Input[builtins.int]] = None,
            renewal_status: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'RegistryEnterpriseInstance':
        """
        Get an existing RegistryEnterpriseInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] created_time: . Field 'created_time' has been deprecated from provider version 1.235.0. New field 'create_time' instead.
        :param pulumi.Input[builtins.str] custom_oss_bucket: Custom OSS Bucket name
        :param pulumi.Input[builtins.str] default_oss_bucket: Whether to use the default OSS Bucket. Value:
        :param pulumi.Input[builtins.str] end_time: Expiration Time
        :param pulumi.Input[builtins.str] image_scanner: The security scan engine used by the Enterprise Edition of Container Image Service. Value:
               - `ACR`: Uses the Trivy scan engine provided by default.
               - `SAS`: uses the enhanced cloud security scan engine.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RegistryEnterpriseInstanceInstanceEndpointArgs', 'RegistryEnterpriseInstanceInstanceEndpointArgsDict']]]] instance_endpoints: (Available since v1.240.0) Instance Network Access Endpoint List
        :param pulumi.Input[builtins.str] instance_name: InstanceName
        :param pulumi.Input[builtins.str] instance_type: The Value configuration of the Group 1 attribute of Container Mirror Service Enterprise Edition. Valid values:
               - `Basic`: Basic instance
               - `Standard`: Standard instance
               - `Advanced`: Advanced Edition Instance
        :param pulumi.Input[builtins.str] kms_encrypted_password: An KMS encrypts password used to an instance. If the `password` is filled in, this field will be ignored.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] kms_encryption_context: An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        :param pulumi.Input[builtins.str] password: Login password, 8-32 digits, must contain at least two letters, symbols, or numbers
        :param pulumi.Input[builtins.str] payment_type: Payment type, value:
               - Subscription: Prepaid.
        :param pulumi.Input[builtins.int] period: Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.
               
               > **NOTE:**  must be set when creating a prepaid instance.
        :param pulumi.Input[builtins.str] region_id: RegionId
        :param pulumi.Input[builtins.int] renew_period: Automatic renewal cycle, in months.
               
               > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        :param pulumi.Input[builtins.str] renewal_status: Automatic renewal status, value:
               - AutoRenewal: automatic renewal.
               - ManualRenewal: manual renewal.
               
               Default ManualRenewal.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        :param pulumi.Input[builtins.str] status: Instance Status
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RegistryEnterpriseInstanceState.__new__(_RegistryEnterpriseInstanceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["custom_oss_bucket"] = custom_oss_bucket
        __props__.__dict__["default_oss_bucket"] = default_oss_bucket
        __props__.__dict__["end_time"] = end_time
        __props__.__dict__["image_scanner"] = image_scanner
        __props__.__dict__["instance_endpoints"] = instance_endpoints
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["kms_encrypted_password"] = kms_encrypted_password
        __props__.__dict__["kms_encryption_context"] = kms_encryption_context
        __props__.__dict__["password"] = password
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["period"] = period
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["renew_period"] = renew_period
        __props__.__dict__["renewal_status"] = renewal_status
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["status"] = status
        return RegistryEnterpriseInstance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="createdTime")
    @_utilities.deprecated("""Field 'created_time' has been deprecated since provider version 1.235.0. New field 'create_time' instead.""")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        . Field 'created_time' has been deprecated from provider version 1.235.0. New field 'create_time' instead.
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customOssBucket")
    def custom_oss_bucket(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Custom OSS Bucket name
        """
        return pulumi.get(self, "custom_oss_bucket")

    @property
    @pulumi.getter(name="defaultOssBucket")
    def default_oss_bucket(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to use the default OSS Bucket. Value:
        """
        return pulumi.get(self, "default_oss_bucket")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Output[builtins.str]:
        """
        Expiration Time
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="imageScanner")
    def image_scanner(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The security scan engine used by the Enterprise Edition of Container Image Service. Value:
        - `ACR`: Uses the Trivy scan engine provided by default.
        - `SAS`: uses the enhanced cloud security scan engine.
        """
        return pulumi.get(self, "image_scanner")

    @property
    @pulumi.getter(name="instanceEndpoints")
    def instance_endpoints(self) -> pulumi.Output[Sequence['outputs.RegistryEnterpriseInstanceInstanceEndpoint']]:
        """
        (Available since v1.240.0) Instance Network Access Endpoint List
        """
        return pulumi.get(self, "instance_endpoints")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[builtins.str]:
        """
        InstanceName
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[builtins.str]:
        """
        The Value configuration of the Group 1 attribute of Container Mirror Service Enterprise Edition. Valid values:
        - `Basic`: Basic instance
        - `Standard`: Standard instance
        - `Advanced`: Advanced Edition Instance
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="kmsEncryptedPassword")
    def kms_encrypted_password(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        An KMS encrypts password used to an instance. If the `password` is filled in, this field will be ignored.
        """
        return pulumi.get(self, "kms_encrypted_password")

    @property
    @pulumi.getter(name="kmsEncryptionContext")
    def kms_encryption_context(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        An KMS encryption context used to decrypt `kms_encrypted_password` before creating or updating instance with `kms_encrypted_password`. See [Encryption Context](https://www.alibabacloud.com/help/doc-detail/42975.htm). It is valid when `kms_encrypted_password` is set.
        """
        return pulumi.get(self, "kms_encryption_context")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Login password, 8-32 digits, must contain at least two letters, symbols, or numbers
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[builtins.str]:
        """
        Payment type, value:
        - Subscription: Prepaid.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.

        > **NOTE:**  must be set when creating a prepaid instance.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        RegionId
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Automatic renewal cycle, in months.

        > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        """
        return pulumi.get(self, "renew_period")

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> pulumi.Output[builtins.str]:
        """
        Automatic renewal status, value:
        - AutoRenewal: automatic renewal.
        - ManualRenewal: manual renewal.

        Default ManualRenewal.
        """
        return pulumi.get(self, "renewal_status")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the resource group

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Instance Status
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RoleArgs', 'Role']

@pulumi.input_type
class RoleArgs:
    def __init__(__self__, *,
                 project_name: pulumi.Input[builtins.str],
                 role_name: pulumi.Input[builtins.str],
                 type: pulumi.Input[builtins.str],
                 policy: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Role resource.
        :param pulumi.Input[builtins.str] project_name: Project name
        :param pulumi.Input[builtins.str] role_name: Role Name
               
               > **NOTE:** At the beginning of a letter, it can contain letters and numbers and can be no more than 64 characters in length.
        :param pulumi.Input[builtins.str] type: Role type Valid values: admin/resource
               
               > **NOTE:** -- management type (admin) role: You can grant management type permissions through Policy. You cannot grant resource permissions to management type roles. You cannot grant management type permissions to management type roles through ACL. -- resource role: you can authorize resource type permissions through Policy or ACL, but cannot authorize management type permissions. For details, see [role-planning](https://www.alibabacloud.com/help/en/maxcompute/user-guide/role-planning)
        :param pulumi.Input[builtins.str] policy: Policy Authorization
               Refer to [Policy-based access control](https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1) and [Authorization practices](https://www.alibabacloud.com/help/en/maxcompute/use-cases/authorization-practices)
        """
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "role_name", role_name)
        pulumi.set(__self__, "type", type)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[builtins.str]:
        """
        Project name
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Input[builtins.str]:
        """
        Role Name

        > **NOTE:** At the beginning of a letter, it can contain letters and numbers and can be no more than 64 characters in length.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        Role type Valid values: admin/resource

        > **NOTE:** -- management type (admin) role: You can grant management type permissions through Policy. You cannot grant resource permissions to management type roles. You cannot grant management type permissions to management type roles through ACL. -- resource role: you can authorize resource type permissions through Policy or ACL, but cannot authorize management type permissions. For details, see [role-planning](https://www.alibabacloud.com/help/en/maxcompute/user-guide/role-planning)
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Policy Authorization
        Refer to [Policy-based access control](https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1) and [Authorization practices](https://www.alibabacloud.com/help/en/maxcompute/use-cases/authorization-practices)
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy", value)


@pulumi.input_type
class _RoleState:
    def __init__(__self__, *,
                 policy: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Role resources.
        :param pulumi.Input[builtins.str] policy: Policy Authorization
               Refer to [Policy-based access control](https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1) and [Authorization practices](https://www.alibabacloud.com/help/en/maxcompute/use-cases/authorization-practices)
        :param pulumi.Input[builtins.str] project_name: Project name
        :param pulumi.Input[builtins.str] role_name: Role Name
               
               > **NOTE:** At the beginning of a letter, it can contain letters and numbers and can be no more than 64 characters in length.
        :param pulumi.Input[builtins.str] type: Role type Valid values: admin/resource
               
               > **NOTE:** -- management type (admin) role: You can grant management type permissions through Policy. You cannot grant resource permissions to management type roles. You cannot grant management type permissions to management type roles through ACL. -- resource role: you can authorize resource type permissions through Policy or ACL, but cannot authorize management type permissions. For details, see [role-planning](https://www.alibabacloud.com/help/en/maxcompute/user-guide/role-planning)
        """
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Policy Authorization
        Refer to [Policy-based access control](https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1) and [Authorization practices](https://www.alibabacloud.com/help/en/maxcompute/use-cases/authorization-practices)
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Project name
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Role Name

        > **NOTE:** At the beginning of a letter, it can contain letters and numbers and can be no more than 64 characters in length.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Role type Valid values: admin/resource

        > **NOTE:** -- management type (admin) role: You can grant management type permissions through Policy. You cannot grant resource permissions to management type roles. You cannot grant management type permissions to management type roles through ACL. -- resource role: you can authorize resource type permissions through Policy or ACL, but cannot authorize management type permissions. For details, see [role-planning](https://www.alibabacloud.com/help/en/maxcompute/user-guide/role-planning)
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("alicloud:maxcompute/role:Role")
class Role(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 policy: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Max Compute Role resource.

        For information about Max Compute Role and how to use it, see [What is Role](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.maxcompute.Project("default",
            default_quota="默认后付费Quota",
            project_name=name,
            comment=name,
            product_type="PayAsYouGo")
        default_role = alicloud.maxcompute.Role("default",
            type="admin",
            project_name=default.id,
            policy=json.dumps({
                "Statement": [{
                    "Action": ["odps:*"],
                    "Effect": "Allow",
                    "Resource": [
                        "acs:odps:*:projects/project_name/authorization/roles",
                        "acs:odps:*:projects/project_name/authorization/roles/*/*",
                    ],
                }],
                "Version": "1",
            }),
            role_name="tf_example112")
        ```

        ## Import

        Max Compute Role can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/role:Role example <project_name>:<role_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] policy: Policy Authorization
               Refer to [Policy-based access control](https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1) and [Authorization practices](https://www.alibabacloud.com/help/en/maxcompute/use-cases/authorization-practices)
        :param pulumi.Input[builtins.str] project_name: Project name
        :param pulumi.Input[builtins.str] role_name: Role Name
               
               > **NOTE:** At the beginning of a letter, it can contain letters and numbers and can be no more than 64 characters in length.
        :param pulumi.Input[builtins.str] type: Role type Valid values: admin/resource
               
               > **NOTE:** -- management type (admin) role: You can grant management type permissions through Policy. You cannot grant resource permissions to management type roles. You cannot grant management type permissions to management type roles through ACL. -- resource role: you can authorize resource type permissions through Policy or ACL, but cannot authorize management type permissions. For details, see [role-planning](https://www.alibabacloud.com/help/en/maxcompute/user-guide/role-planning)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Max Compute Role resource.

        For information about Max Compute Role and how to use it, see [What is Role](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.maxcompute.Project("default",
            default_quota="默认后付费Quota",
            project_name=name,
            comment=name,
            product_type="PayAsYouGo")
        default_role = alicloud.maxcompute.Role("default",
            type="admin",
            project_name=default.id,
            policy=json.dumps({
                "Statement": [{
                    "Action": ["odps:*"],
                    "Effect": "Allow",
                    "Resource": [
                        "acs:odps:*:projects/project_name/authorization/roles",
                        "acs:odps:*:projects/project_name/authorization/roles/*/*",
                    ],
                }],
                "Version": "1",
            }),
            role_name="tf_example112")
        ```

        ## Import

        Max Compute Role can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/role:Role example <project_name>:<role_name>
        ```

        :param str resource_name: The name of the resource.
        :param RoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 policy: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleArgs.__new__(RoleArgs)

            __props__.__dict__["policy"] = policy
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            if role_name is None and not opts.urn:
                raise TypeError("Missing required property 'role_name'")
            __props__.__dict__["role_name"] = role_name
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(Role, __self__).__init__(
            'alicloud:maxcompute/role:Role',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            policy: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            role_name: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'Role':
        """
        Get an existing Role resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] policy: Policy Authorization
               Refer to [Policy-based access control](https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1) and [Authorization practices](https://www.alibabacloud.com/help/en/maxcompute/use-cases/authorization-practices)
        :param pulumi.Input[builtins.str] project_name: Project name
        :param pulumi.Input[builtins.str] role_name: Role Name
               
               > **NOTE:** At the beginning of a letter, it can contain letters and numbers and can be no more than 64 characters in length.
        :param pulumi.Input[builtins.str] type: Role type Valid values: admin/resource
               
               > **NOTE:** -- management type (admin) role: You can grant management type permissions through Policy. You cannot grant resource permissions to management type roles. You cannot grant management type permissions to management type roles through ACL. -- resource role: you can authorize resource type permissions through Policy or ACL, but cannot authorize management type permissions. For details, see [role-planning](https://www.alibabacloud.com/help/en/maxcompute/user-guide/role-planning)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleState.__new__(_RoleState)

        __props__.__dict__["policy"] = policy
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["role_name"] = role_name
        __props__.__dict__["type"] = type
        return Role(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Policy Authorization
        Refer to [Policy-based access control](https://www.alibabacloud.com/help/en/maxcompute/user-guide/policy-based-access-control-1) and [Authorization practices](https://www.alibabacloud.com/help/en/maxcompute/use-cases/authorization-practices)
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        Project name
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[builtins.str]:
        """
        Role Name

        > **NOTE:** At the beginning of a letter, it can contain letters and numbers and can be no more than 64 characters in length.
        """
        return pulumi.get(self, "role_name")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Role type Valid values: admin/resource

        > **NOTE:** -- management type (admin) role: You can grant management type permissions through Policy. You cannot grant resource permissions to management type roles. You cannot grant management type permissions to management type roles through ACL. -- resource role: you can authorize resource type permissions through Policy or ACL, but cannot authorize management type permissions. For details, see [role-planning](https://www.alibabacloud.com/help/en/maxcompute/user-guide/role-planning)
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HttpResponseHeaderModificationRuleArgs', 'HttpResponseHeaderModificationRule']

@pulumi.input_type
class HttpResponseHeaderModificationRuleArgs:
    def __init__(__self__, *,
                 response_header_modifications: pulumi.Input[Sequence[pulumi.Input['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs']]],
                 site_id: pulumi.Input[builtins.int],
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a HttpResponseHeaderModificationRule resource.
        :param pulumi.Input[Sequence[pulumi.Input['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs']]] response_header_modifications: Modify response headers, supporting add, delete, and modify operations. See `response_header_modification` below.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.str] rule: Rule content.
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. Possible values:
        :param pulumi.Input[builtins.str] rule_name: Rule name.
        :param pulumi.Input[builtins.int] site_version: The version number of the website configurations.
        """
        pulumi.set(__self__, "response_header_modifications", response_header_modifications)
        pulumi.set(__self__, "site_id", site_id)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="responseHeaderModifications")
    def response_header_modifications(self) -> pulumi.Input[Sequence[pulumi.Input['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs']]]:
        """
        Modify response headers, supporting add, delete, and modify operations. See `response_header_modification` below.
        """
        return pulumi.get(self, "response_header_modifications")

    @response_header_modifications.setter
    def response_header_modifications(self, value: pulumi.Input[Sequence[pulumi.Input['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs']]]):
        pulumi.set(self, "response_header_modifications", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content.
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. Possible values:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the website configurations.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.input_type
class _HttpResponseHeaderModificationRuleState:
    def __init__(__self__, *,
                 config_id: Optional[pulumi.Input[builtins.int]] = None,
                 response_header_modifications: Optional[pulumi.Input[Sequence[pulumi.Input['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs']]]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering HttpResponseHeaderModificationRule resources.
        :param pulumi.Input[builtins.int] config_id: Config Id
        :param pulumi.Input[Sequence[pulumi.Input['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs']]] response_header_modifications: Modify response headers, supporting add, delete, and modify operations. See `response_header_modification` below.
        :param pulumi.Input[builtins.str] rule: Rule content.
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. Possible values:
        :param pulumi.Input[builtins.str] rule_name: Rule name.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.int] site_version: The version number of the website configurations.
        """
        if config_id is not None:
            pulumi.set(__self__, "config_id", config_id)
        if response_header_modifications is not None:
            pulumi.set(__self__, "response_header_modifications", response_header_modifications)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Config Id
        """
        return pulumi.get(self, "config_id")

    @config_id.setter
    def config_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "config_id", value)

    @property
    @pulumi.getter(name="responseHeaderModifications")
    def response_header_modifications(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs']]]]:
        """
        Modify response headers, supporting add, delete, and modify operations. See `response_header_modification` below.
        """
        return pulumi.get(self, "response_header_modifications")

    @response_header_modifications.setter
    def response_header_modifications(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs']]]]):
        pulumi.set(self, "response_header_modifications", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content.
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. Possible values:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the website configurations.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.type_token("alicloud:esa/httpResponseHeaderModificationRule:HttpResponseHeaderModificationRule")
class HttpResponseHeaderModificationRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 response_header_modifications: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs', 'HttpResponseHeaderModificationRuleResponseHeaderModificationArgsDict']]]]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a ESA Http Response Header Modification Rule resource.

        For information about ESA Http Response Header Modification Rule and how to use it, see [What is Http Response Header Modification Rule](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/api-esa-2024-09-10-createhttpresponseheadermodificationrule).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        resource_http_response_header_modification_rule_example = alicloud.esa.RatePlanInstance("resource_HttpResponseHeaderModificationRule_example",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        resource_site_http_response_header_modification_rule_example = alicloud.esa.Site("resource_Site_HttpResponseHeaderModificationRule_example",
            site_name=f"gositecdn-{default['result']}.cn",
            instance_id=resource_http_response_header_modification_rule_example.id,
            coverage="overseas",
            access_type="NS")
        default_http_response_header_modification_rule = alicloud.esa.HttpResponseHeaderModificationRule("default",
            rule_enable="on",
            response_header_modifications=[
                {
                    "value": "add",
                    "operation": "add",
                    "name": "exampleadd",
                },
                {
                    "operation": "del",
                    "name": "exampledel",
                },
                {
                    "operation": "modify",
                    "name": "examplemodify",
                    "value": "modify",
                },
            ],
            rule="(http.host eq \\"video.example.com\\")",
            site_version=0,
            rule_name="exampleResponseHeader",
            site_id=resource_site_http_response_header_modification_rule_example.id)
        ```

        ## Import

        ESA Http Response Header Modification Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/httpResponseHeaderModificationRule:HttpResponseHeaderModificationRule example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs', 'HttpResponseHeaderModificationRuleResponseHeaderModificationArgsDict']]]] response_header_modifications: Modify response headers, supporting add, delete, and modify operations. See `response_header_modification` below.
        :param pulumi.Input[builtins.str] rule: Rule content.
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. Possible values:
        :param pulumi.Input[builtins.str] rule_name: Rule name.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.int] site_version: The version number of the website configurations.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HttpResponseHeaderModificationRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Http Response Header Modification Rule resource.

        For information about ESA Http Response Header Modification Rule and how to use it, see [What is Http Response Header Modification Rule](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/api-esa-2024-09-10-createhttpresponseheadermodificationrule).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        resource_http_response_header_modification_rule_example = alicloud.esa.RatePlanInstance("resource_HttpResponseHeaderModificationRule_example",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        resource_site_http_response_header_modification_rule_example = alicloud.esa.Site("resource_Site_HttpResponseHeaderModificationRule_example",
            site_name=f"gositecdn-{default['result']}.cn",
            instance_id=resource_http_response_header_modification_rule_example.id,
            coverage="overseas",
            access_type="NS")
        default_http_response_header_modification_rule = alicloud.esa.HttpResponseHeaderModificationRule("default",
            rule_enable="on",
            response_header_modifications=[
                {
                    "value": "add",
                    "operation": "add",
                    "name": "exampleadd",
                },
                {
                    "operation": "del",
                    "name": "exampledel",
                },
                {
                    "operation": "modify",
                    "name": "examplemodify",
                    "value": "modify",
                },
            ],
            rule="(http.host eq \\"video.example.com\\")",
            site_version=0,
            rule_name="exampleResponseHeader",
            site_id=resource_site_http_response_header_modification_rule_example.id)
        ```

        ## Import

        ESA Http Response Header Modification Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/httpResponseHeaderModificationRule:HttpResponseHeaderModificationRule example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param HttpResponseHeaderModificationRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HttpResponseHeaderModificationRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 response_header_modifications: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs', 'HttpResponseHeaderModificationRuleResponseHeaderModificationArgsDict']]]]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HttpResponseHeaderModificationRuleArgs.__new__(HttpResponseHeaderModificationRuleArgs)

            if response_header_modifications is None and not opts.urn:
                raise TypeError("Missing required property 'response_header_modifications'")
            __props__.__dict__["response_header_modifications"] = response_header_modifications
            __props__.__dict__["rule"] = rule
            __props__.__dict__["rule_enable"] = rule_enable
            __props__.__dict__["rule_name"] = rule_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["site_version"] = site_version
            __props__.__dict__["config_id"] = None
        super(HttpResponseHeaderModificationRule, __self__).__init__(
            'alicloud:esa/httpResponseHeaderModificationRule:HttpResponseHeaderModificationRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_id: Optional[pulumi.Input[builtins.int]] = None,
            response_header_modifications: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs', 'HttpResponseHeaderModificationRuleResponseHeaderModificationArgsDict']]]]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_enable: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            site_version: Optional[pulumi.Input[builtins.int]] = None) -> 'HttpResponseHeaderModificationRule':
        """
        Get an existing HttpResponseHeaderModificationRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] config_id: Config Id
        :param pulumi.Input[Sequence[pulumi.Input[Union['HttpResponseHeaderModificationRuleResponseHeaderModificationArgs', 'HttpResponseHeaderModificationRuleResponseHeaderModificationArgsDict']]]] response_header_modifications: Modify response headers, supporting add, delete, and modify operations. See `response_header_modification` below.
        :param pulumi.Input[builtins.str] rule: Rule content.
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. Possible values:
        :param pulumi.Input[builtins.str] rule_name: Rule name.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.int] site_version: The version number of the website configurations.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HttpResponseHeaderModificationRuleState.__new__(_HttpResponseHeaderModificationRuleState)

        __props__.__dict__["config_id"] = config_id
        __props__.__dict__["response_header_modifications"] = response_header_modifications
        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_enable"] = rule_enable
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["site_version"] = site_version
        return HttpResponseHeaderModificationRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> pulumi.Output[builtins.int]:
        """
        Config Id
        """
        return pulumi.get(self, "config_id")

    @property
    @pulumi.getter(name="responseHeaderModifications")
    def response_header_modifications(self) -> pulumi.Output[Sequence['outputs.HttpResponseHeaderModificationRuleResponseHeaderModification']]:
        """
        Modify response headers, supporting add, delete, and modify operations. See `response_header_modification` below.
        """
        return pulumi.get(self, "response_header_modifications")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule content.
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule switch. Possible values:
        """
        return pulumi.get(self, "rule_enable")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule name.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The version number of the website configurations.
        """
        return pulumi.get(self, "site_version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AssetSelectionConfigArgs', 'AssetSelectionConfig']

@pulumi.input_type
class AssetSelectionConfigArgs:
    def __init__(__self__, *,
                 business_type: pulumi.Input[builtins.str],
                 target_type: pulumi.Input[builtins.str],
                 platform: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a AssetSelectionConfig resource.
        :param pulumi.Input[builtins.str] business_type: The first ID of the resource
        :param pulumi.Input[builtins.str] target_type: Target object type.
        :param pulumi.Input[builtins.str] platform: The operating system type.
        """
        pulumi.set(__self__, "business_type", business_type)
        pulumi.set(__self__, "target_type", target_type)
        if platform is not None:
            pulumi.set(__self__, "platform", platform)

    @property
    @pulumi.getter(name="businessType")
    def business_type(self) -> pulumi.Input[builtins.str]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "business_type")

    @business_type.setter
    def business_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "business_type", value)

    @property
    @pulumi.getter(name="targetType")
    def target_type(self) -> pulumi.Input[builtins.str]:
        """
        Target object type.
        """
        return pulumi.get(self, "target_type")

    @target_type.setter
    def target_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "target_type", value)

    @property
    @pulumi.getter
    def platform(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The operating system type.
        """
        return pulumi.get(self, "platform")

    @platform.setter
    def platform(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "platform", value)


@pulumi.input_type
class _AssetSelectionConfigState:
    def __init__(__self__, *,
                 business_type: Optional[pulumi.Input[builtins.str]] = None,
                 platform: Optional[pulumi.Input[builtins.str]] = None,
                 target_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering AssetSelectionConfig resources.
        :param pulumi.Input[builtins.str] business_type: The first ID of the resource
        :param pulumi.Input[builtins.str] platform: The operating system type.
        :param pulumi.Input[builtins.str] target_type: Target object type.
        """
        if business_type is not None:
            pulumi.set(__self__, "business_type", business_type)
        if platform is not None:
            pulumi.set(__self__, "platform", platform)
        if target_type is not None:
            pulumi.set(__self__, "target_type", target_type)

    @property
    @pulumi.getter(name="businessType")
    def business_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "business_type")

    @business_type.setter
    def business_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_type", value)

    @property
    @pulumi.getter
    def platform(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The operating system type.
        """
        return pulumi.get(self, "platform")

    @platform.setter
    def platform(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "platform", value)

    @property
    @pulumi.getter(name="targetType")
    def target_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Target object type.
        """
        return pulumi.get(self, "target_type")

    @target_type.setter
    def target_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "target_type", value)


@pulumi.type_token("alicloud:threatdetection/assetSelectionConfig:AssetSelectionConfig")
class AssetSelectionConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 business_type: Optional[pulumi.Input[builtins.str]] = None,
                 platform: Optional[pulumi.Input[builtins.str]] = None,
                 target_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        Threat Detection Asset Selection Config can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:threatdetection/assetSelectionConfig:AssetSelectionConfig example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] business_type: The first ID of the resource
        :param pulumi.Input[builtins.str] platform: The operating system type.
        :param pulumi.Input[builtins.str] target_type: Target object type.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AssetSelectionConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Threat Detection Asset Selection Config can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:threatdetection/assetSelectionConfig:AssetSelectionConfig example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AssetSelectionConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AssetSelectionConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 business_type: Optional[pulumi.Input[builtins.str]] = None,
                 platform: Optional[pulumi.Input[builtins.str]] = None,
                 target_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AssetSelectionConfigArgs.__new__(AssetSelectionConfigArgs)

            if business_type is None and not opts.urn:
                raise TypeError("Missing required property 'business_type'")
            __props__.__dict__["business_type"] = business_type
            __props__.__dict__["platform"] = platform
            if target_type is None and not opts.urn:
                raise TypeError("Missing required property 'target_type'")
            __props__.__dict__["target_type"] = target_type
        super(AssetSelectionConfig, __self__).__init__(
            'alicloud:threatdetection/assetSelectionConfig:AssetSelectionConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            business_type: Optional[pulumi.Input[builtins.str]] = None,
            platform: Optional[pulumi.Input[builtins.str]] = None,
            target_type: Optional[pulumi.Input[builtins.str]] = None) -> 'AssetSelectionConfig':
        """
        Get an existing AssetSelectionConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] business_type: The first ID of the resource
        :param pulumi.Input[builtins.str] platform: The operating system type.
        :param pulumi.Input[builtins.str] target_type: Target object type.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AssetSelectionConfigState.__new__(_AssetSelectionConfigState)

        __props__.__dict__["business_type"] = business_type
        __props__.__dict__["platform"] = platform
        __props__.__dict__["target_type"] = target_type
        return AssetSelectionConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="businessType")
    def business_type(self) -> pulumi.Output[builtins.str]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "business_type")

    @property
    @pulumi.getter
    def platform(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The operating system type.
        """
        return pulumi.get(self, "platform")

    @property
    @pulumi.getter(name="targetType")
    def target_type(self) -> pulumi.Output[builtins.str]:
        """
        Target object type.
        """
        return pulumi.get(self, "target_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSecurityPoliciesResult',
    'AwaitableGetSecurityPoliciesResult',
    'get_security_policies',
    'get_security_policies_output',
]

@pulumi.output_type
class GetSecurityPoliciesResult:
    """
    A collection of values returned by getSecurityPolicies.
    """
    def __init__(__self__, id=None, ids=None, name_regex=None, names=None, output_file=None, policies=None, resource_group_id=None, security_policy_names=None, status=None, tags=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if security_policy_names and not isinstance(security_policy_names, list):
            raise TypeError("Expected argument 'security_policy_names' to be a list")
        pulumi.set(__self__, "security_policy_names", security_policy_names)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetSecurityPoliciesPolicyResult']:
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="securityPolicyNames")
    def security_policy_names(self) -> Optional[Sequence[builtins.str]]:
        return pulumi.get(self, "security_policy_names")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        return pulumi.get(self, "tags")


class AwaitableGetSecurityPoliciesResult(GetSecurityPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecurityPoliciesResult(
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            policies=self.policies,
            resource_group_id=self.resource_group_id,
            security_policy_names=self.security_policy_names,
            status=self.status,
            tags=self.tags)


def get_security_policies(ids: Optional[Sequence[builtins.str]] = None,
                          name_regex: Optional[builtins.str] = None,
                          output_file: Optional[builtins.str] = None,
                          resource_group_id: Optional[builtins.str] = None,
                          security_policy_names: Optional[Sequence[builtins.str]] = None,
                          status: Optional[builtins.str] = None,
                          tags: Optional[Mapping[str, builtins.str]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecurityPoliciesResult:
    """
    This data source provides the Nlb Security Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.187.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.nlb.get_security_policies()
    pulumi.export("nlbSecurityPolicyId1", ids.policies[0].id)
    name_regex = alicloud.nlb.get_security_policies(name_regex="^my-SecurityPolicy")
    pulumi.export("nlbSecurityPolicyId2", name_regex.policies[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Security Policy IDs.
    :param builtins.str name_regex: A regex string to filter results by Security Policy name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The ID of the resource group.
    :param Sequence[builtins.str] security_policy_names: The names of the TLS security policies.
    :param builtins.str status: The status of the resource. Valid values: `Available`, `Configuring`.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['securityPolicyNames'] = security_policy_names
    __args__['status'] = status
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:nlb/getSecurityPolicies:getSecurityPolicies', __args__, opts=opts, typ=GetSecurityPoliciesResult).value

    return AwaitableGetSecurityPoliciesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        policies=pulumi.get(__ret__, 'policies'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        security_policy_names=pulumi.get(__ret__, 'security_policy_names'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'))
def get_security_policies_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                 name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 resource_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 security_policy_names: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                 status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 tags: Optional[pulumi.Input[Optional[Mapping[str, builtins.str]]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecurityPoliciesResult]:
    """
    This data source provides the Nlb Security Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.187.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.nlb.get_security_policies()
    pulumi.export("nlbSecurityPolicyId1", ids.policies[0].id)
    name_regex = alicloud.nlb.get_security_policies(name_regex="^my-SecurityPolicy")
    pulumi.export("nlbSecurityPolicyId2", name_regex.policies[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Security Policy IDs.
    :param builtins.str name_regex: A regex string to filter results by Security Policy name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The ID of the resource group.
    :param Sequence[builtins.str] security_policy_names: The names of the TLS security policies.
    :param builtins.str status: The status of the resource. Valid values: `Available`, `Configuring`.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['securityPolicyNames'] = security_policy_names
    __args__['status'] = status
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:nlb/getSecurityPolicies:getSecurityPolicies', __args__, opts=opts, typ=GetSecurityPoliciesResult)
    return __ret__.apply(lambda __response__: GetSecurityPoliciesResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        policies=pulumi.get(__response__, 'policies'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        security_policy_names=pulumi.get(__response__, 'security_policy_names'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSitesResult',
    'AwaitableGetSitesResult',
    'get_sites',
    'get_sites_output',
]

@pulumi.output_type
class GetSitesResult:
    """
    A collection of values returned by getSites.
    """
    def __init__(__self__, access_type=None, coverage=None, id=None, ids=None, name_regex=None, names=None, only_enterprise=None, output_file=None, page_number=None, page_size=None, plan_subscribe_type=None, resource_group_id=None, site_name=None, site_search_type=None, sites=None, status=None, tags=None):
        if access_type and not isinstance(access_type, str):
            raise TypeError("Expected argument 'access_type' to be a str")
        pulumi.set(__self__, "access_type", access_type)
        if coverage and not isinstance(coverage, str):
            raise TypeError("Expected argument 'coverage' to be a str")
        pulumi.set(__self__, "coverage", coverage)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if only_enterprise and not isinstance(only_enterprise, bool):
            raise TypeError("Expected argument 'only_enterprise' to be a bool")
        pulumi.set(__self__, "only_enterprise", only_enterprise)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if plan_subscribe_type and not isinstance(plan_subscribe_type, str):
            raise TypeError("Expected argument 'plan_subscribe_type' to be a str")
        pulumi.set(__self__, "plan_subscribe_type", plan_subscribe_type)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if site_name and not isinstance(site_name, str):
            raise TypeError("Expected argument 'site_name' to be a str")
        pulumi.set(__self__, "site_name", site_name)
        if site_search_type and not isinstance(site_search_type, str):
            raise TypeError("Expected argument 'site_search_type' to be a str")
        pulumi.set(__self__, "site_search_type", site_search_type)
        if sites and not isinstance(sites, list):
            raise TypeError("Expected argument 'sites' to be a list")
        pulumi.set(__self__, "sites", sites)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="accessType")
    def access_type(self) -> Optional[builtins.str]:
        """
        Access type. Value:-**NS**: Managed access via NS.-**CNAME**: access through CNAME.
        """
        return pulumi.get(self, "access_type")

    @property
    @pulumi.getter
    def coverage(self) -> Optional[builtins.str]:
        """
        Acceleration area
        """
        return pulumi.get(self, "coverage")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Site IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of name of Sites.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="onlyEnterprise")
    def only_enterprise(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "only_enterprise")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="planSubscribeType")
    def plan_subscribe_type(self) -> Optional[builtins.str]:
        return pulumi.get(self, "plan_subscribe_type")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[builtins.str]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="siteName")
    def site_name(self) -> Optional[builtins.str]:
        """
        Site Name
        """
        return pulumi.get(self, "site_name")

    @property
    @pulumi.getter(name="siteSearchType")
    def site_search_type(self) -> Optional[builtins.str]:
        return pulumi.get(self, "site_search_type")

    @property
    @pulumi.getter
    def sites(self) -> Sequence['outputs.GetSitesSiteResult']:
        """
        A list of Site Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "sites")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        return pulumi.get(self, "tags")


class AwaitableGetSitesResult(GetSitesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSitesResult(
            access_type=self.access_type,
            coverage=self.coverage,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            only_enterprise=self.only_enterprise,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            plan_subscribe_type=self.plan_subscribe_type,
            resource_group_id=self.resource_group_id,
            site_name=self.site_name,
            site_search_type=self.site_search_type,
            sites=self.sites,
            status=self.status,
            tags=self.tags)


def get_sites(access_type: Optional[builtins.str] = None,
              coverage: Optional[builtins.str] = None,
              ids: Optional[Sequence[builtins.str]] = None,
              name_regex: Optional[builtins.str] = None,
              only_enterprise: Optional[builtins.bool] = None,
              output_file: Optional[builtins.str] = None,
              page_number: Optional[builtins.int] = None,
              page_size: Optional[builtins.int] = None,
              plan_subscribe_type: Optional[builtins.str] = None,
              resource_group_id: Optional[builtins.str] = None,
              site_name: Optional[builtins.str] = None,
              site_search_type: Optional[builtins.str] = None,
              status: Optional[builtins.str] = None,
              tags: Optional[Mapping[str, builtins.str]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSitesResult:
    """
    This data source provides Esa Site available to the user.[What is Site](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateSite)

    > **NOTE:** Available since v1.244.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default_i_eo_df_u = alicloud.esa.RatePlanInstance("defaultIEoDfU",
        type="NS",
        auto_renew=True,
        period=1,
        payment_type="Subscription",
        coverage="overseas",
        auto_pay=True,
        plan_name="basic")
    default_site = alicloud.esa.Site("default",
        site_name="bcd.com",
        coverage="overseas",
        access_type="NS",
        instance_id=default_i_eo_df_u.id)
    default = alicloud.esa.get_sites_output(ids=[default_site.id],
        name_regex=default_site.site_name,
        site_name="bcd.com")
    pulumi.export("alicloudEsaSiteExampleId", default.sites[0].id)
    ```


    :param builtins.str access_type: Access type. Value:-**NS**: Managed access via NS.-**CNAME**: access through CNAME.
    :param builtins.str coverage: Acceleration area
    :param Sequence[builtins.str] ids: A list of Site IDs.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.bool only_enterprise: Only the Enterprise version, pass **true** when the table only queries the enterprise version of the site.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.int page_number: Current page number.
    :param builtins.int page_size: Number of records per page.
    :param builtins.str plan_subscribe_type: Package subscription type. Value:-**basicplan**: Basic version.-**standardplan**: Standard version.-**advancedplan**: Advanced version.-**enterpriseplan**: Enterprise Edition.
    :param builtins.str resource_group_id: The ID of the resource group
    :param builtins.str site_name: Site Name
    :param builtins.str site_search_type: The search match pattern for the site name. The default value is exact match. Valid values:-**prefix**: matches the prefix.-**suffix**: The suffix matches.-**exact**: exact match.-**fuzzy**: fuzzy match.
    :param builtins.str status: The status of the resource
    :param Mapping[str, builtins.str] tags: Resource tags
    """
    __args__ = dict()
    __args__['accessType'] = access_type
    __args__['coverage'] = coverage
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['onlyEnterprise'] = only_enterprise
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['planSubscribeType'] = plan_subscribe_type
    __args__['resourceGroupId'] = resource_group_id
    __args__['siteName'] = site_name
    __args__['siteSearchType'] = site_search_type
    __args__['status'] = status
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:esa/getSites:getSites', __args__, opts=opts, typ=GetSitesResult).value

    return AwaitableGetSitesResult(
        access_type=pulumi.get(__ret__, 'access_type'),
        coverage=pulumi.get(__ret__, 'coverage'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        only_enterprise=pulumi.get(__ret__, 'only_enterprise'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        plan_subscribe_type=pulumi.get(__ret__, 'plan_subscribe_type'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        site_name=pulumi.get(__ret__, 'site_name'),
        site_search_type=pulumi.get(__ret__, 'site_search_type'),
        sites=pulumi.get(__ret__, 'sites'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'))
def get_sites_output(access_type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     coverage: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                     name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     only_enterprise: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                     output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     page_number: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                     page_size: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                     plan_subscribe_type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     resource_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     site_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     site_search_type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     tags: Optional[pulumi.Input[Optional[Mapping[str, builtins.str]]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSitesResult]:
    """
    This data source provides Esa Site available to the user.[What is Site](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateSite)

    > **NOTE:** Available since v1.244.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default_i_eo_df_u = alicloud.esa.RatePlanInstance("defaultIEoDfU",
        type="NS",
        auto_renew=True,
        period=1,
        payment_type="Subscription",
        coverage="overseas",
        auto_pay=True,
        plan_name="basic")
    default_site = alicloud.esa.Site("default",
        site_name="bcd.com",
        coverage="overseas",
        access_type="NS",
        instance_id=default_i_eo_df_u.id)
    default = alicloud.esa.get_sites_output(ids=[default_site.id],
        name_regex=default_site.site_name,
        site_name="bcd.com")
    pulumi.export("alicloudEsaSiteExampleId", default.sites[0].id)
    ```


    :param builtins.str access_type: Access type. Value:-**NS**: Managed access via NS.-**CNAME**: access through CNAME.
    :param builtins.str coverage: Acceleration area
    :param Sequence[builtins.str] ids: A list of Site IDs.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.bool only_enterprise: Only the Enterprise version, pass **true** when the table only queries the enterprise version of the site.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.int page_number: Current page number.
    :param builtins.int page_size: Number of records per page.
    :param builtins.str plan_subscribe_type: Package subscription type. Value:-**basicplan**: Basic version.-**standardplan**: Standard version.-**advancedplan**: Advanced version.-**enterpriseplan**: Enterprise Edition.
    :param builtins.str resource_group_id: The ID of the resource group
    :param builtins.str site_name: Site Name
    :param builtins.str site_search_type: The search match pattern for the site name. The default value is exact match. Valid values:-**prefix**: matches the prefix.-**suffix**: The suffix matches.-**exact**: exact match.-**fuzzy**: fuzzy match.
    :param builtins.str status: The status of the resource
    :param Mapping[str, builtins.str] tags: Resource tags
    """
    __args__ = dict()
    __args__['accessType'] = access_type
    __args__['coverage'] = coverage
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['onlyEnterprise'] = only_enterprise
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['planSubscribeType'] = plan_subscribe_type
    __args__['resourceGroupId'] = resource_group_id
    __args__['siteName'] = site_name
    __args__['siteSearchType'] = site_search_type
    __args__['status'] = status
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:esa/getSites:getSites', __args__, opts=opts, typ=GetSitesResult)
    return __ret__.apply(lambda __response__: GetSitesResult(
        access_type=pulumi.get(__response__, 'access_type'),
        coverage=pulumi.get(__response__, 'coverage'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        only_enterprise=pulumi.get(__response__, 'only_enterprise'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        plan_subscribe_type=pulumi.get(__response__, 'plan_subscribe_type'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        site_name=pulumi.get(__response__, 'site_name'),
        site_search_type=pulumi.get(__response__, 'site_search_type'),
        sites=pulumi.get(__response__, 'sites'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags')))
